@@ -24,4 +24,12 @@ ALTER EXTENSION pg_hint_plan UPDATE TO "1.3.9";
 \dx+ pg_hint_plan
 ALTER EXTENSION pg_hint_plan UPDATE TO "1.3.10";
 \dx+ pg_hint_plan
+ALTER EXTENSION pg_hint_plan UPDATE TO "1.4";
+\dx+ pg_hint_plan
+ALTER EXTENSION pg_hint_plan UPDATE TO "1.4.1";
+\dx+ pg_hint_plan
+ALTER EXTENSION pg_hint_plan UPDATE TO "1.4.2";
+\dx+ pg_hint_plan
+ALTER EXTENSION pg_hint_plan UPDATE TO "1.4.3";
+\dx+ pg_hint_plan
 DROP EXTENSION pg_hint_plan;
